@@ -7,6 +7,6 @@ test_that("autotest", {
   expect_learner(learner)
 
   skip_on_os("solaris")
-  result = run_autotest(learner, exclude = "(feat_single|sanity)", check_replicable = FALSE)
+  result = run_autotest(learner, exclude = "feat_single", check_replicable = FALSE)
   expect_true(result, info = result$error)
 })
